bittivahti
==========

A simple local network interface bandwidth monitor tool for Linux.

Installation
------------

.. code-block:: console

  $ pip install bittivahti

.. code-block:: console

 bittivahti 0.9.2
 interface   |      RX bw / packets |      TX bw / packets | total:  RX       TX 
 lo          |   0.0 kB/s    0  p/s |   0.0 kB/s    0  p/s |     0.0 kB   0.0 kB
 br1         |   0.0 kB/s    0  p/s |   0.0 kB/s    0  p/s |     0.0 kB   0.0 kB
 br0         |   0.1 kB/s    2  p/s |   0.7 kB/s    6  p/s |     0.9 kB   2.6 kB
 vnet0       |   0.0 kB/s    0  p/s |   0.0 kB/s    0  p/s |     0.0 kB   0.1 kB
 vnet1       |   0.0 kB/s    0  p/s |   0.0 kB/s    0  p/s |     0.0 kB   0.0 kB
 eth4        |   0.1 kB/s    2  p/s |   0.7 kB/s    6  p/s |     1.1 kB   2.7 kB
 
